@@ -327,7 +327,7 @@ plot.SimulationMeanDate <- function(x, calendar = getOption("kairos.calendar"),
   ## Add annotation
   if (ann) {
     ## Caption
-    cap <- sprintf("Simulated assemblages, %d replications.", NCOL(x@replications))
+    cap <- sprintf(tr_("Simulated assemblages, %d replications."), NCOL(x@replications))
     xlab <- format(calendar)
     ylab <- NULL
     graphics::title(main = main, sub = sub, xlab = xlab, ylab = ylab, ...)
@@ -360,20 +360,3 @@ conf <- function(x, type = c("percentiles", "student", "normal", "range"),
   names(result) <- c("mean", "lower", "upper")
   result
 }
-
-#' Plotting Dimensions of Character Strings
-#'
-#' Convert string length in inch to number of (margin) lines.
-#' @param x A [`character`] vector of string whose length is to be calculated.
-#' @param ... Further parameter to be passed to [graphics::strwidth()]`, such as
-#'  `cex`.
-#' @return
-#'  A [`numeric`] vector (maximum string width in units of margin lines).
-#' @note For internal use only.
-#' @family graphic tools
-#' @keywords internal
-#' @noRd
-inch2line <- function(x, ...) {
-  (max(graphics::strwidth(x, units = "inch", ...)) /
-     graphics::par("cin")[2] + graphics::par("mgp")[2]) * graphics::par("cex")
-}
