@@ -1,13 +1,5 @@
 # REEXPORT FROM ARKHE
 
-#' @importFrom arkhe bootstrap
-#' @export
-arkhe::bootstrap
-
-#' @importFrom arkhe jackknife
-#' @export
-arkhe::jackknife
-
 #' @importFrom arkhe replace_NA
 #' @export
 arkhe::replace_NA
@@ -24,6 +16,10 @@ arkhe::remove_NA
 #' @export
 arkhe::remove_zero
 
+#' @importFrom arkhe remove_constant
+#' @export
+arkhe::remove_constant
+
 #' @importFrom aion calendar
 #' @export
 aion::calendar
